@@ -6,8 +6,11 @@
 
 module Reactive.Banana (
     module Reactive.Banana.Combinators,
-    module Reactive.Banana.Frameworks,
+    module Reactive.Banana.Switch,
+    compile,
     ) where
 
 import Reactive.Banana.Combinators
 import Reactive.Banana.Frameworks
+import Reactive.Banana.Internal.Types2
+import Reactive.Banana.Switch
\ No newline at end of file
